==> startsite-15-v8.2.2.tar.gz: var/www/t3sources/ext/startsite-15/Configuration/TCA/Overrides/sys_template.php <==
<?php

use TYPO3\CMS\Core\Utility\ExtensionManagementUtility;

defined('TYPO3') or die;

//\TYPO3\CMS\Core\Utility\ExtensionManagementUtility::addStaticFile(

// base
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript', 'Startsite 15 - librerie di base (mysite.settings)');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/backgroundsReset', 'Startsite: background Reset');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/rowsDemo', 'Startsite: mostra le row da riempire con gli snippets');

// templates
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/templates/center', 'Startsite preset:  center/advanced');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/templates/linear', 'Startsite preset:  linear/advanced');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/templates/offcanvas', 'Startsite prerset:  offcanvas/advanced');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/templates/office', 'Startsite preset: office/advanced');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/templates/personal', 'Startsite preset:  personal/advanced');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/templates/uniud', 'Startsite preset:  uniud/advanced');


// subtemplates
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/sub-templates/offcanvas-office-style', 'Startsite sub-template:  offcanvas stile office');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/sub-templates/offcanvas-only', 'Startsite sub-template:  offcanvas only');


// snippets
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/annoCorrente', 'Startsite snippet:  anno corrente lib.annoCorrente');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/cookie-bar-klaro', 'Startsite snippet: cookie bar klaro, no libs');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/dataOggi', 'Startsite snippet: data corrente, lib.dataOggi');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/datiOrganizzazione', 'Startsite snippet: dati azienda/ente, lib.datiOrganizzazione/datiFiscali');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/facebook-domain-verification', 'Startsite snippet: facebook domain verification');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/google-tag-manager', 'Startsite snippet: google tag manager');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/indexedSearchBox', 'Startsite snippet: indexed search searchbox, lib.indexedSearchBox');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/ke_searchBox', 'Startsite snippet: ke_search searchbox, lib.ke_searchbox_html');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/layerSlider-6.2.1', 'Startsite snippet: layerslider 6.2.1');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/layerSlider-6.7.5', 'Startsite snippet: layerslider 6.7.5');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/logoBrand', 'Startsite snippet: logo brand, lib.logoBrand');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/sessionButtons', 'Startsite snippet: session buttons, lib.loginButton/logoutButton');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/menuLingueFlag', 'Startsite snippet: menu lingue a bandiera, lib.menuLingueFlag');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/menuLingueText', 'Startsite snippet: menu lingue solo testo, lib.menuLingueText');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/navigation-prevnext', 'Startsite snippet: navigazione prev/next, lib.navigation-prevnext');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/pulsantePrenota', 'Startsite snippet: pulsante prenota, lib.pulsantePrenota');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/simpleBooking', 'Startsite snippet: simple booking');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/socialBookmarks', 'Startsite snippet: social bookmarks, lib.socialBookmarks');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/zopim', 'Startsite snippet: zopim, varie lib');

==> startsite-15-v8.2.4.tar.gz: var/www/t3sources/ext/startsite-15/Configuration/TCA/Overrides/sys_template.php <==
<?php

use TYPO3\CMS\Core\Utility\ExtensionManagementUtility;

defined('TYPO3') or die;

//\TYPO3\CMS\Core\Utility\ExtensionManagementUtility::addStaticFile(

// base
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript', 'Startsite 15 - librerie di base (mysite.settings)');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/chunks/backgroundsReset', 'Startsite: background Reset');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/chunks/menus/offcanvas/', 'Startsite: force offcanvas menu');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/rowsDemo', 'Startsite: mostra le row da riempire con gli snippets');

// templates
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/templates/center', 'Startsite preset:  center/advanced');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/templates/linear', 'Startsite preset:  linear/advanced');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/templates/offcanvas', 'Startsite prerset:  offcanvas/advanced');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/templates/office', 'Startsite preset: office/advanced');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/templates/personal', 'Startsite preset:  personal/advanced');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/templates/uniud', 'Startsite preset:  uniud/advanced');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/templates/tourist', 'Startsite preset:  tourist/sidebar (default)');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/templates/tourist-offcanvas', 'Startsite preset:  tourist/sidebar + offcanvas');


// subtemplates
// non va: ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/sub-templates/offcanvas', 'Startsite sub-template:  offcanvas (libreria di base)');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/sub-templates/offcanvas-office-style', 'Startsite sub-template:  offcanvas stile office');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/sub-templates/offcanvas-only', 'Startsite sub-template:  offcanvas only');


// snippets
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/annoCorrente', 'Startsite snippet:  anno corrente lib.annoCorrente');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/cookie-bar-klaro', 'Startsite snippet: cookie bar klaro, no libs');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/dataOggi', 'Startsite snippet: data corrente, lib.dataOggi');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/datiOrganizzazione', 'Startsite snippet: dati azienda/ente, lib.datiOrganizzazione/datiFiscali');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/facebook-domain-verification', 'Startsite snippet: facebook domain verification');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/google-tag-manager', 'Startsite snippet: google tag manager');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/indexedSearchBox', 'Startsite snippet: indexed search searchbox, lib.indexedSearchBox');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/ke_searchBox', 'Startsite snippet: ke_search searchbox, lib.ke_searchbox_html');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/layerSlider-6.2.1', 'Startsite snippet: layerslider 6.2.1');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/layerSlider-6.7.5', 'Startsite snippet: layerslider 6.7.5');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/logoBrand', 'Startsite snippet: logo brand, lib.logoBrand');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/sessionButtons', 'Startsite snippet: session buttons, lib.loginButton/logoutButton');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/menuLingueFlag', 'Startsite snippet: menu lingue a bandiera, lib.menuLingueFlag');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/menuLingueText', 'Startsite snippet: menu lingue solo testo, lib.menuLingueText');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/navigation-prevnext', 'Startsite snippet: navigazione prev/next, lib.navigation-prevnext');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/pulsantePrenota', 'Startsite snippet: pulsante prenota, lib.pulsantePrenota');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/simpleBooking', 'Startsite snippet: simple booking');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/socialBookmarks', 'Startsite snippet: social bookmarks, lib.socialBookmarks');
ExtensionManagementUtility::addStaticFile('startsite', 'Configuration/TypoScript/ts-snippets/zopim', 'Startsite snippet: zopim, varie lib');
